@@ -1,7 +1,7 @@
 """
  Adapted from https://github.com/pyqtgraph/pyqtgraph/blob/master/pyqtgraph/flowchart/FlowchartGraphicsView.py
 """
-from pyqtgraph.Qt import QtGui, QtCore
+from pyqtgraph.Qt import QtGui, QtCore, QtWidgets
 from pyqtgraph.widgets.GraphicsView import GraphicsView
 from pyqtgraph.graphicsItems.ViewBox import ViewBox
 
@@ -28,4 +28,13 @@ class RxViewBox(ViewBox):
         self.widget = widget
 
     def getMenu(self, ev):
-        return QtGui.QMenu()
+        ## called by ViewBox to create a new context menu
+        self._fc_menu = QtWidgets.QMenu()
+        self._subMenus = self.getContextMenus(ev)
+        for menu in self._subMenus:
+            self._fc_menu.addMenu(menu)
+        return self._fc_menu
+
+    def getContextMenus(self, ev):
+        ## called by scene to add menus on to someone else's context menu
+        return [ViewBox.getMenu(self, ev)]
